@@ -87,20 +87,33 @@ abstract class CoreAuthModPDO extends CoreAuthModule {
         return $this->DB->count('-user-count', array('name' => $name));
     }
 
-    private function checkUserAuth($bTrustUsername = AUTH_NOT_TRUST_USERNAME) {
-        if($bTrustUsername === AUTH_NOT_TRUST_USERNAME) {
-            $res = $this->DB->query('-user-get-by-pass', array('name' => $this->sUsername, 'password' => $this->sPasswordHash));
-        } else {
-            $res = $this->DB->query('-user-get-by-name', array('name' => $this->sUsername));
-        }
-
-        $data = $res->fetch();
-
+    private function checkUserAuth() {
+        $data = $this->DB->query('-user-get-by-pass', array('name' => $this->sUsername, 'password' => $this->sPasswordHash))->fetch();
         if (!isset($data['userId']))
             return 0;
         return intval($data['userId']);
     }
 
+    private function getTrustedUser() {
+        $data = $this->DB->query('-user-get-by-name', array('name' => $this->sUsername))->fetch();
+        if (!isset($data['userId']))
+            return 0;
+        return intval($data['userId']);
+    }
+
+    private function checkBcryptAuth() {
+        if ($this->sPassword === '') {
+            return $this->checkUserAuth();
+        }
+        $data = $this->DB->query('-user-get-pw-hash', array('name' => $this->sUsername))->fetch();
+        $password_hash = $data['password'];
+        if (!password_verify($this->sPassword, $password_hash)) {
+            return 0;
+        }
+        $this->sPasswordHash = $password_hash;
+        return $this->getTrustedUser();
+    }
+
     private function updatePassword($uid, $pw) {
         try {
             $res = $this->DB->query('-user-update-pass', array('id' => $uid, 'password' => $pw));
@@ -190,22 +203,44 @@ abstract class CoreAuthModPDO extends CoreAuthModule {
         if($this->sUsername === '' || !$this->checkUserExists($this->sUsername))
             return false;
 
-        // Try to calculate the passowrd hash only when no hash is known at
+        $use_bcrypt = $this->usesBcrypt($this->sUsername);
+        // Try to calculate the password hash only when no hash is known at
         // this time. For example when the user just entered the password
         // for logging in. If the user is already logged in and this is just
         // a session check don't try to rehash the password.
-        if($bTrustUsername === AUTH_NOT_TRUST_USERNAME && $this->sPasswordHash === '') {
+        if($bTrustUsername === AUTH_NOT_TRUST_USERNAME && $this->sPasswordHash === '' && !$use_bcrypt) {
             // Compose the password hash for comparing with the stored hash
-            $this->sPasswordHash = $this->createHash($this->sPassword);
+            $this->sPasswordHash = $this->oldHash($this->sPassword);
+        }
+
+        if ($bTrustUsername === AUTH_TRUST_USERNAME) {
+            $userId = $this->getTrustedUser();
+        } else if ($use_bcrypt) {
+            $userId = $this->checkBcryptAuth();
+        } else {
+            $userId = $this->checkUserAuth();
         }
 
-        // Check the password hash
-        $userId = $this->checkUserAuth($bTrustUsername);
         if($userId > 0) {
             $this->iUserId = $userId;
+            // If the user authenticates successfully with an old hash for the first time the password is rewritten
+            // with a bcrypt hash.
+            if (!$use_bcrypt && $this->sPassword !== '') {
+                $password_hash = $this->createHash($this->sPassword);
+                $this->updatePassword($userId, $password_hash);
+                $this->sPasswordHash = $password_hash;
+            }
             return true;
         }
+        return false;
+    }
 
+    public function usesBcrypt($username) {
+        $data = $this->DB->query('-user-get-pw-hash', array('name' => $username))->fetch();
+        if (!isset($data['password']))
+            return false;
+        if (substr($data['password'], 0, 4) == '$2y$')
+            return true;
         return false;
     }
 
@@ -217,8 +252,12 @@ abstract class CoreAuthModPDO extends CoreAuthModule {
         return $this->iUserId;
     }
 
-    private function createHash($password) {
+    private function oldHash($password) {
         return sha1(AUTH_PASSWORD_SALT.$password);
     }
+
+    private function createHash($password) {
+        return password_hash($password, PASSWORD_BCRYPT);
+    }
 }
 ?>
